# -*- coding: utf-8 -*-

# Form implementation generated from reading ui file 'DeclaTravaux/ui/main_window.ui'
#
# Created by: PyQt5 UI code generator 5.10.1
#
# WARNING! All changes made in this file will be lost!

from PyQt5 import QtCore, QtGui, QtWidgets

class Ui_Main_Window(object):
    def setupUi(self, Main_Window):
        Main_Window.setObjectName("Main_Window")
        Main_Window.resize(600, 475)
        Main_Window.setMinimumSize(QtCore.QSize(600, 475))
        Main_Window.setMaximumSize(QtCore.QSize(600, 475))
        self.centralWidget = QtWidgets.QWidget(Main_Window)
        self.centralWidget.setObjectName("centralWidget")
        self.verticalLayout_2 = QtWidgets.QVBoxLayout(self.centralWidget)
        self.verticalLayout_2.setContentsMargins(11, 11, 11, 11)
        self.verticalLayout_2.setSpacing(6)
        self.verticalLayout_2.setObjectName("verticalLayout_2")
        self.stackedWidget = QtWidgets.QStackedWidget(self.centralWidget)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Preferred, QtWidgets.QSizePolicy.MinimumExpanding)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.stackedWidget.sizePolicy().hasHeightForWidth())
        self.stackedWidget.setSizePolicy(sizePolicy)
        self.stackedWidget.setMinimumSize(QtCore.QSize(0, 400))
        self.stackedWidget.setObjectName("stackedWidget")
        self.pageStart = QtWidgets.QWidget()
        self.pageStart.setObjectName("pageStart")
        self.verticalLayout = QtWidgets.QVBoxLayout(self.pageStart)
        self.verticalLayout.setContentsMargins(11, 11, 11, 11)
        self.verticalLayout.setSpacing(6)
        self.verticalLayout.setObjectName("verticalLayout")
        spacerItem = QtWidgets.QSpacerItem(20, 40, QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.MinimumExpanding)
        self.verticalLayout.addItem(spacerItem)
        self.labelTitle1 = QtWidgets.QLabel(self.pageStart)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Preferred, QtWidgets.QSizePolicy.Preferred)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.labelTitle1.sizePolicy().hasHeightForWidth())
        self.labelTitle1.setSizePolicy(sizePolicy)
        self.labelTitle1.setMinimumSize(QtCore.QSize(0, 0))
        font = QtGui.QFont()
        font.setPointSize(16)
        font.setBold(True)
        font.setWeight(75)
        self.labelTitle1.setFont(font)
        self.labelTitle1.setAutoFillBackground(False)
        self.labelTitle1.setStyleSheet("")
        self.labelTitle1.setAlignment(QtCore.Qt.AlignCenter)
        self.labelTitle1.setIndent(0)
        self.labelTitle1.setObjectName("labelTitle1")
        self.verticalLayout.addWidget(self.labelTitle1)
        self.labelTitle2 = QtWidgets.QLabel(self.pageStart)
        self.labelTitle2.setMinimumSize(QtCore.QSize(0, 0))
        font = QtGui.QFont()
        font.setPointSize(13)
        font.setBold(False)
        font.setWeight(50)
        self.labelTitle2.setFont(font)
        self.labelTitle2.setStyleSheet("")
        self.labelTitle2.setAlignment(QtCore.Qt.AlignCenter)
        self.labelTitle2.setIndent(0)
        self.labelTitle2.setObjectName("labelTitle2")
        self.verticalLayout.addWidget(self.labelTitle2)
        spacerItem1 = QtWidgets.QSpacerItem(20, 20, QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Fixed)
        self.verticalLayout.addItem(spacerItem1)
        self.horizontalLayout_3 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_3.setSpacing(6)
        self.horizontalLayout_3.setObjectName("horizontalLayout_3")
        spacerItem2 = QtWidgets.QSpacerItem(40, 20, QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Minimum)
        self.horizontalLayout_3.addItem(spacerItem2)
        self.pushButtonAbout = QtWidgets.QPushButton(self.pageStart)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Fixed, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.pushButtonAbout.sizePolicy().hasHeightForWidth())
        self.pushButtonAbout.setSizePolicy(sizePolicy)
        self.pushButtonAbout.setStyleSheet("")
        icon = QtGui.QIcon.fromTheme("help-about")
        self.pushButtonAbout.setIcon(icon)
        self.pushButtonAbout.setCheckable(True)
        self.pushButtonAbout.setAutoDefault(True)
        self.pushButtonAbout.setObjectName("pushButtonAbout")
        self.horizontalLayout_3.addWidget(self.pushButtonAbout)
        spacerItem3 = QtWidgets.QSpacerItem(40, 20, QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Minimum)
        self.horizontalLayout_3.addItem(spacerItem3)
        self.verticalLayout.addLayout(self.horizontalLayout_3)
        spacerItem4 = QtWidgets.QSpacerItem(20, 10, QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Fixed)
        self.verticalLayout.addItem(spacerItem4)
        self.textBrowserAbout = QtWidgets.QTextBrowser(self.pageStart)
        self.textBrowserAbout.setEnabled(True)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.MinimumExpanding)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.textBrowserAbout.sizePolicy().hasHeightForWidth())
        self.textBrowserAbout.setSizePolicy(sizePolicy)
        self.textBrowserAbout.setMinimumSize(QtCore.QSize(0, 0))
        font = QtGui.QFont()
        font.setPointSize(10)
        self.textBrowserAbout.setFont(font)
        self.textBrowserAbout.setStyleSheet("background-color: rgba(255, 255, 255, 0);\n"
"color: gray;")
        self.textBrowserAbout.setFrameShape(QtWidgets.QFrame.NoFrame)
        self.textBrowserAbout.setFrameShadow(QtWidgets.QFrame.Sunken)
        self.textBrowserAbout.setLineWidth(0)
        self.textBrowserAbout.setOpenExternalLinks(True)
        self.textBrowserAbout.setObjectName("textBrowserAbout")
        self.verticalLayout.addWidget(self.textBrowserAbout)
        spacerItem5 = QtWidgets.QSpacerItem(20, 20, QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.MinimumExpanding)
        self.verticalLayout.addItem(spacerItem5)
        self.stackedWidget.addWidget(self.pageStart)
        self.pageParameters = QtWidgets.QWidget()
        self.pageParameters.setObjectName("pageParameters")
        self.verticalLayout_4 = QtWidgets.QVBoxLayout(self.pageParameters)
        self.verticalLayout_4.setContentsMargins(11, 15, 11, 15)
        self.verticalLayout_4.setSpacing(15)
        self.verticalLayout_4.setObjectName("verticalLayout_4")
        self.labelTitleParameters = QtWidgets.QLabel(self.pageParameters)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Preferred, QtWidgets.QSizePolicy.Expanding)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.labelTitleParameters.sizePolicy().hasHeightForWidth())
        self.labelTitleParameters.setSizePolicy(sizePolicy)
        self.labelTitleParameters.setMinimumSize(QtCore.QSize(0, 0))
        font = QtGui.QFont()
        font.setPointSize(16)
        font.setBold(True)
        font.setWeight(75)
        self.labelTitleParameters.setFont(font)
        self.labelTitleParameters.setStyleSheet("")
        self.labelTitleParameters.setAlignment(QtCore.Qt.AlignCenter)
        self.labelTitleParameters.setIndent(0)
        self.labelTitleParameters.setObjectName("labelTitleParameters")
        self.verticalLayout_4.addWidget(self.labelTitleParameters)
        self.groupBox = QtWidgets.QGroupBox(self.pageParameters)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Preferred, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.groupBox.sizePolicy().hasHeightForWidth())
        self.groupBox.setSizePolicy(sizePolicy)
        self.groupBox.setMinimumSize(QtCore.QSize(0, 0))
        self.groupBox.setMaximumSize(QtCore.QSize(16777215, 16777215))
        self.groupBox.setStyleSheet("QGroupBox {\n"
"    border: 1px solid gray;\n"
"    margin-top: 0.5em;\n"
"}\n"
"\n"
"QGroupBox::title {\n"
"    subcontrol-origin: margin;\n"
"    left: 10px;\n"
"    padding: 0 5px 0 5px;\n"
"}")
        self.groupBox.setObjectName("groupBox")
        self.gridLayout = QtWidgets.QGridLayout(self.groupBox)
        self.gridLayout.setContentsMargins(11, 11, 11, 11)
        self.gridLayout.setSpacing(6)
        self.gridLayout.setObjectName("gridLayout")
        self.labelSearchDir = QtWidgets.QLabel(self.groupBox)
        self.labelSearchDir.setMinimumSize(QtCore.QSize(0, 30))
        self.labelSearchDir.setMaximumSize(QtCore.QSize(16777215, 30))
        self.labelSearchDir.setStyleSheet("")
        self.labelSearchDir.setObjectName("labelSearchDir")
        self.gridLayout.addWidget(self.labelSearchDir, 0, 0, 1, 1)
        self.labelWorkDir = QtWidgets.QLabel(self.groupBox)
        self.labelWorkDir.setMinimumSize(QtCore.QSize(0, 30))
        self.labelWorkDir.setMaximumSize(QtCore.QSize(16777215, 30))
        self.labelWorkDir.setObjectName("labelWorkDir")
        self.gridLayout.addWidget(self.labelWorkDir, 1, 0, 1, 1)
        self.horizontalLayout_8 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_8.setSizeConstraint(QtWidgets.QLayout.SetDefaultConstraint)
        self.horizontalLayout_8.setContentsMargins(0, 0, 0, 0)
        self.horizontalLayout_8.setSpacing(0)
        self.horizontalLayout_8.setObjectName("horizontalLayout_8")
        self.pushButtonWorkDir = QtWidgets.QPushButton(self.groupBox)
        self.pushButtonWorkDir.setMinimumSize(QtCore.QSize(30, 30))
        self.pushButtonWorkDir.setMaximumSize(QtCore.QSize(30, 30))
        self.pushButtonWorkDir.setAutoDefault(True)
        self.pushButtonWorkDir.setObjectName("pushButtonWorkDir")
        self.horizontalLayout_8.addWidget(self.pushButtonWorkDir)
        self.lineEditWorkDir = QtWidgets.QLineEdit(self.groupBox)
        self.lineEditWorkDir.setEnabled(True)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.lineEditWorkDir.sizePolicy().hasHeightForWidth())
        self.lineEditWorkDir.setSizePolicy(sizePolicy)
        self.lineEditWorkDir.setMinimumSize(QtCore.QSize(0, 30))
        self.lineEditWorkDir.setMaximumSize(QtCore.QSize(16777215, 30))
        self.lineEditWorkDir.setReadOnly(True)
        self.lineEditWorkDir.setObjectName("lineEditWorkDir")
        self.horizontalLayout_8.addWidget(self.lineEditWorkDir)
        self.gridLayout.addLayout(self.horizontalLayout_8, 1, 1, 1, 1)
        self.horizontalLayout_7 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_7.setSizeConstraint(QtWidgets.QLayout.SetDefaultConstraint)
        self.horizontalLayout_7.setContentsMargins(0, 0, 0, 0)
        self.horizontalLayout_7.setSpacing(0)
        self.horizontalLayout_7.setObjectName("horizontalLayout_7")
        self.pushButtonSearchDir = QtWidgets.QPushButton(self.groupBox)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Fixed, QtWidgets.QSizePolicy.Expanding)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.pushButtonSearchDir.sizePolicy().hasHeightForWidth())
        self.pushButtonSearchDir.setSizePolicy(sizePolicy)
        self.pushButtonSearchDir.setMinimumSize(QtCore.QSize(30, 30))
        self.pushButtonSearchDir.setMaximumSize(QtCore.QSize(30, 30))
        self.pushButtonSearchDir.setStyleSheet("border-width: 1px;")
        self.pushButtonSearchDir.setAutoDefault(True)
        self.pushButtonSearchDir.setObjectName("pushButtonSearchDir")
        self.horizontalLayout_7.addWidget(self.pushButtonSearchDir)
        self.lineEditSearchDir = QtWidgets.QLineEdit(self.groupBox)
        self.lineEditSearchDir.setEnabled(True)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.lineEditSearchDir.sizePolicy().hasHeightForWidth())
        self.lineEditSearchDir.setSizePolicy(sizePolicy)
        self.lineEditSearchDir.setMinimumSize(QtCore.QSize(0, 30))
        self.lineEditSearchDir.setMaximumSize(QtCore.QSize(16777215, 30))
        self.lineEditSearchDir.setStyleSheet("")
        self.lineEditSearchDir.setInputMask("")
        self.lineEditSearchDir.setReadOnly(True)
        self.lineEditSearchDir.setPlaceholderText("")
        self.lineEditSearchDir.setClearButtonEnabled(False)
        self.lineEditSearchDir.setObjectName("lineEditSearchDir")
        self.horizontalLayout_7.addWidget(self.lineEditSearchDir)
        self.gridLayout.addLayout(self.horizontalLayout_7, 0, 1, 1, 1)
        self.verticalLayout_4.addWidget(self.groupBox)
        self.groupBox_2 = QtWidgets.QGroupBox(self.pageParameters)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Preferred, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.groupBox_2.sizePolicy().hasHeightForWidth())
        self.groupBox_2.setSizePolicy(sizePolicy)
        self.groupBox_2.setStyleSheet("QGroupBox {\n"
"    border: 1px solid gray;\n"
"    margin-top: 0.5em;\n"
"}\n"
"\n"
"QGroupBox::title {\n"
"    subcontrol-origin: margin;\n"
"    left: 10px;\n"
"    padding: 0 5px 0 5px;\n"
"}")
        self.groupBox_2.setObjectName("groupBox_2")
        self.gridLayout_2 = QtWidgets.QGridLayout(self.groupBox_2)
        self.gridLayout_2.setContentsMargins(11, 11, 11, 11)
        self.gridLayout_2.setSpacing(6)
        self.gridLayout_2.setObjectName("gridLayout_2")
        self.horizontalWidget = QtWidgets.QWidget(self.groupBox_2)
        self.horizontalWidget.setObjectName("horizontalWidget")
        self.horizontalLayout_4 = QtWidgets.QHBoxLayout(self.horizontalWidget)
        self.horizontalLayout_4.setContentsMargins(0, 0, 0, 0)
        self.horizontalLayout_4.setSpacing(0)
        self.horizontalLayout_4.setObjectName("horizontalLayout_4")
        self.lineEditPassword = QtWidgets.QLineEdit(self.horizontalWidget)
        self.lineEditPassword.setEnabled(True)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.lineEditPassword.sizePolicy().hasHeightForWidth())
        self.lineEditPassword.setSizePolicy(sizePolicy)
        self.lineEditPassword.setMinimumSize(QtCore.QSize(0, 30))
        self.lineEditPassword.setMaximumSize(QtCore.QSize(16777215, 30))
        self.lineEditPassword.setEchoMode(QtWidgets.QLineEdit.Password)
        self.lineEditPassword.setObjectName("lineEditPassword")
        self.horizontalLayout_4.addWidget(self.lineEditPassword)
        self.gridLayout_2.addWidget(self.horizontalWidget, 1, 1, 1, 1)
        self.labelSmtpServer = QtWidgets.QLabel(self.groupBox_2)
        self.labelSmtpServer.setMinimumSize(QtCore.QSize(0, 30))
        self.labelSmtpServer.setMaximumSize(QtCore.QSize(16777215, 30))
        self.labelSmtpServer.setObjectName("labelSmtpServer")
        self.gridLayout_2.addWidget(self.labelSmtpServer, 2, 0, 1, 1)
        self.lineEditSmtpServer = QtWidgets.QLineEdit(self.groupBox_2)
        self.lineEditSmtpServer.setMinimumSize(QtCore.QSize(0, 30))
        self.lineEditSmtpServer.setMaximumSize(QtCore.QSize(16777215, 30))
        self.lineEditSmtpServer.setInputMask("")
        self.lineEditSmtpServer.setClearButtonEnabled(True)
        self.lineEditSmtpServer.setObjectName("lineEditSmtpServer")
        self.gridLayout_2.addWidget(self.lineEditSmtpServer, 2, 1, 1, 1)
        self.lineEditSmtpPort = QtWidgets.QLineEdit(self.groupBox_2)
        self.lineEditSmtpPort.setMinimumSize(QtCore.QSize(0, 30))
        self.lineEditSmtpPort.setMaximumSize(QtCore.QSize(16777215, 30))
        self.lineEditSmtpPort.setClearButtonEnabled(True)
        self.lineEditSmtpPort.setObjectName("lineEditSmtpPort")
        self.gridLayout_2.addWidget(self.lineEditSmtpPort, 3, 1, 1, 1)
        self.labelMail = QtWidgets.QLabel(self.groupBox_2)
        self.labelMail.setMinimumSize(QtCore.QSize(0, 30))
        self.labelMail.setMaximumSize(QtCore.QSize(16777215, 30))
        self.labelMail.setObjectName("labelMail")
        self.gridLayout_2.addWidget(self.labelMail, 0, 0, 1, 1)
        self.lineEditExpeditorName = QtWidgets.QLineEdit(self.groupBox_2)
        self.lineEditExpeditorName.setMinimumSize(QtCore.QSize(0, 29))
        self.lineEditExpeditorName.setMaximumSize(QtCore.QSize(16777215, 29))
        self.lineEditExpeditorName.setClearButtonEnabled(True)
        self.lineEditExpeditorName.setObjectName("lineEditExpeditorName")
        self.gridLayout_2.addWidget(self.lineEditExpeditorName, 4, 1, 1, 1)
        self.labelSmtpPort = QtWidgets.QLabel(self.groupBox_2)
        self.labelSmtpPort.setMinimumSize(QtCore.QSize(0, 30))
        self.labelSmtpPort.setMaximumSize(QtCore.QSize(16777215, 30))
        self.labelSmtpPort.setObjectName("labelSmtpPort")
        self.gridLayout_2.addWidget(self.labelSmtpPort, 3, 0, 1, 1)
        self.label = QtWidgets.QLabel(self.groupBox_2)
        self.label.setEnabled(True)
        self.label.setMinimumSize(QtCore.QSize(0, 30))
        self.label.setMaximumSize(QtCore.QSize(16777215, 30))
        self.label.setObjectName("label")
        self.gridLayout_2.addWidget(self.label, 1, 0, 1, 1)
        self.labelExpeditorName = QtWidgets.QLabel(self.groupBox_2)
        self.labelExpeditorName.setMinimumSize(QtCore.QSize(0, 30))
        self.labelExpeditorName.setMaximumSize(QtCore.QSize(16777215, 30))
        self.labelExpeditorName.setObjectName("labelExpeditorName")
        self.gridLayout_2.addWidget(self.labelExpeditorName, 4, 0, 1, 1)
        self.lineEditMail = QtWidgets.QLineEdit(self.groupBox_2)
        self.lineEditMail.setMinimumSize(QtCore.QSize(0, 30))
        self.lineEditMail.setMaximumSize(QtCore.QSize(16777215, 30))
        self.lineEditMail.setText("")
        self.lineEditMail.setClearButtonEnabled(True)
        self.lineEditMail.setObjectName("lineEditMail")
        self.gridLayout_2.addWidget(self.lineEditMail, 0, 1, 1, 1)
        self.verticalLayout_4.addWidget(self.groupBox_2)
        self.stackedWidget.addWidget(self.pageParameters)
        self.pageFileSelection = QtWidgets.QWidget()
        self.pageFileSelection.setObjectName("pageFileSelection")
        self.verticalLayout_10 = QtWidgets.QVBoxLayout(self.pageFileSelection)
        self.verticalLayout_10.setContentsMargins(11, 11, 11, 11)
        self.verticalLayout_10.setSpacing(6)
        self.verticalLayout_10.setObjectName("verticalLayout_10")
        self.verticalLayout_3 = QtWidgets.QVBoxLayout()
        self.verticalLayout_3.setContentsMargins(-1, -1, -1, 10)
        self.verticalLayout_3.setSpacing(0)
        self.verticalLayout_3.setObjectName("verticalLayout_3")
        spacerItem6 = QtWidgets.QSpacerItem(561, 125, QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Expanding)
        self.verticalLayout_3.addItem(spacerItem6)
        self.labelFileSelection = QtWidgets.QLabel(self.pageFileSelection)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Preferred, QtWidgets.QSizePolicy.Preferred)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.labelFileSelection.sizePolicy().hasHeightForWidth())
        self.labelFileSelection.setSizePolicy(sizePolicy)
        font = QtGui.QFont()
        font.setPointSize(13)
        font.setBold(False)
        font.setWeight(50)
        self.labelFileSelection.setFont(font)
        self.labelFileSelection.setAlignment(QtCore.Qt.AlignCenter)
        self.labelFileSelection.setObjectName("labelFileSelection")
        self.verticalLayout_3.addWidget(self.labelFileSelection)
        self.verticalLayout_10.addLayout(self.verticalLayout_3)
        self.horizontalLayout_2 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_2.setSpacing(0)
        self.horizontalLayout_2.setObjectName("horizontalLayout_2")
        self.lineEditFile = QtWidgets.QLineEdit(self.pageFileSelection)
        self.lineEditFile.setMinimumSize(QtCore.QSize(0, 30))
        self.lineEditFile.setMaximumSize(QtCore.QSize(16777215, 30))
        self.lineEditFile.setObjectName("lineEditFile")
        self.horizontalLayout_2.addWidget(self.lineEditFile)
        self.pushButtonBrowse = QtWidgets.QPushButton(self.pageFileSelection)
        self.pushButtonBrowse.setMinimumSize(QtCore.QSize(0, 30))
        self.pushButtonBrowse.setMaximumSize(QtCore.QSize(16777215, 30))
        self.pushButtonBrowse.setAutoDefault(True)
        self.pushButtonBrowse.setObjectName("pushButtonBrowse")
        self.horizontalLayout_2.addWidget(self.pushButtonBrowse)
        self.verticalLayout_10.addLayout(self.horizontalLayout_2)
        self.verticalLayout_9 = QtWidgets.QVBoxLayout()
        self.verticalLayout_9.setContentsMargins(-1, 0, -1, -1)
        self.verticalLayout_9.setSpacing(0)
        self.verticalLayout_9.setObjectName("verticalLayout_9")
        self.labelFileError = QtWidgets.QLabel(self.pageFileSelection)
        font = QtGui.QFont()
        font.setItalic(True)
        self.labelFileError.setFont(font)
        self.labelFileError.setStyleSheet("color: rgb(226,87,76);")
        self.labelFileError.setAlignment(QtCore.Qt.AlignCenter)
        self.labelFileError.setObjectName("labelFileError")
        self.verticalLayout_9.addWidget(self.labelFileError)
        spacerItem7 = QtWidgets.QSpacerItem(561, 125, QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Expanding)
        self.verticalLayout_9.addItem(spacerItem7)
        self.verticalLayout_10.addLayout(self.verticalLayout_9)
        self.stackedWidget.addWidget(self.pageFileSelection)
        self.pageArchiveChoose = QtWidgets.QWidget()
        self.pageArchiveChoose.setObjectName("pageArchiveChoose")
        self.verticalLayout_7 = QtWidgets.QVBoxLayout(self.pageArchiveChoose)
        self.verticalLayout_7.setContentsMargins(11, 11, 11, 11)
        self.verticalLayout_7.setSpacing(15)
        self.verticalLayout_7.setObjectName("verticalLayout_7")
        spacerItem8 = QtWidgets.QSpacerItem(20, 32, QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Expanding)
        self.verticalLayout_7.addItem(spacerItem8)
        self.label_2 = QtWidgets.QLabel(self.pageArchiveChoose)
        font = QtGui.QFont()
        font.setPointSize(13)
        self.label_2.setFont(font)
        self.label_2.setAlignment(QtCore.Qt.AlignCenter)
        self.label_2.setObjectName("label_2")
        self.verticalLayout_7.addWidget(self.label_2)
        self.label_3 = QtWidgets.QLabel(self.pageArchiveChoose)
        font = QtGui.QFont()
        font.setPointSize(13)
        self.label_3.setFont(font)
        self.label_3.setAlignment(QtCore.Qt.AlignCenter)
        self.label_3.setObjectName("label_3")
        self.verticalLayout_7.addWidget(self.label_3)
        spacerItem9 = QtWidgets.QSpacerItem(20, 15, QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Fixed)
        self.verticalLayout_7.addItem(spacerItem9)
        self.listWidget = QtWidgets.QListWidget(self.pageArchiveChoose)
        font = QtGui.QFont()
        font.setPointSize(12)
        self.listWidget.setFont(font)
        self.listWidget.setViewMode(QtWidgets.QListView.ListMode)
        self.listWidget.setObjectName("listWidget")
        self.verticalLayout_7.addWidget(self.listWidget)
        spacerItem10 = QtWidgets.QSpacerItem(20, 32, QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Expanding)
        self.verticalLayout_7.addItem(spacerItem10)
        self.stackedWidget.addWidget(self.pageArchiveChoose)
        self.pageConfirmation = QtWidgets.QWidget()
        self.pageConfirmation.setObjectName("pageConfirmation")
        self.verticalLayout_5 = QtWidgets.QVBoxLayout(self.pageConfirmation)
        self.verticalLayout_5.setContentsMargins(11, 11, 11, 11)
        self.verticalLayout_5.setSpacing(6)
        self.verticalLayout_5.setObjectName("verticalLayout_5")
        spacerItem11 = QtWidgets.QSpacerItem(20, 133, QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Expanding)
        self.verticalLayout_5.addItem(spacerItem11)
        self.labelConfirmation = QtWidgets.QLabel(self.pageConfirmation)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Preferred, QtWidgets.QSizePolicy.Expanding)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.labelConfirmation.sizePolicy().hasHeightForWidth())
        self.labelConfirmation.setSizePolicy(sizePolicy)
        self.labelConfirmation.setMinimumSize(QtCore.QSize(0, 0))
        self.labelConfirmation.setMaximumSize(QtCore.QSize(16777215, 16777215))
        self.labelConfirmation.setStyleSheet("")
        self.labelConfirmation.setWordWrap(True)
        self.labelConfirmation.setObjectName("labelConfirmation")
        self.verticalLayout_5.addWidget(self.labelConfirmation)
        spacerItem12 = QtWidgets.QSpacerItem(20, 133, QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Expanding)
        self.verticalLayout_5.addItem(spacerItem12)
        self.stackedWidget.addWidget(self.pageConfirmation)
        self.pageProgress = QtWidgets.QWidget()
        self.pageProgress.setObjectName("pageProgress")
        self.verticalLayout_6 = QtWidgets.QVBoxLayout(self.pageProgress)
        self.verticalLayout_6.setContentsMargins(11, 11, 11, 11)
        self.verticalLayout_6.setSpacing(15)
        self.verticalLayout_6.setObjectName("verticalLayout_6")
        spacerItem13 = QtWidgets.QSpacerItem(20, 171, QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Expanding)
        self.verticalLayout_6.addItem(spacerItem13)
        self.progressBar = QtWidgets.QProgressBar(self.pageProgress)
        self.progressBar.setMaximum(100)
        self.progressBar.setProperty("value", 0)
        self.progressBar.setTextVisible(True)
        self.progressBar.setObjectName("progressBar")
        self.verticalLayout_6.addWidget(self.progressBar)
        self.labelStep = QtWidgets.QLabel(self.pageProgress)
        self.labelStep.setStyleSheet("font: italic;")
        self.labelStep.setAlignment(QtCore.Qt.AlignCenter)
        self.labelStep.setObjectName("labelStep")
        self.verticalLayout_6.addWidget(self.labelStep)
        spacerItem14 = QtWidgets.QSpacerItem(20, 170, QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Expanding)
        self.verticalLayout_6.addItem(spacerItem14)
        self.stackedWidget.addWidget(self.pageProgress)
        self.pageEnd = QtWidgets.QWidget()
        self.pageEnd.setObjectName("pageEnd")
        self.verticalLayout_8 = QtWidgets.QVBoxLayout(self.pageEnd)
        self.verticalLayout_8.setContentsMargins(11, 11, 11, 11)
        self.verticalLayout_8.setSpacing(6)
        self.verticalLayout_8.setObjectName("verticalLayout_8")
        spacerItem15 = QtWidgets.QSpacerItem(20, 20, QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.MinimumExpanding)
        self.verticalLayout_8.addItem(spacerItem15)
        self.horizontalLayout_6 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_6.setSpacing(6)
        self.horizontalLayout_6.setObjectName("horizontalLayout_6")
        spacerItem16 = QtWidgets.QSpacerItem(40, 20, QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Minimum)
        self.horizontalLayout_6.addItem(spacerItem16)
        self.labelEndIcon = QtWidgets.QLabel(self.pageEnd)
        self.labelEndIcon.setMinimumSize(QtCore.QSize(100, 100))
        self.labelEndIcon.setMaximumSize(QtCore.QSize(100, 100))
        self.labelEndIcon.setText("")
        self.labelEndIcon.setScaledContents(True)
        self.labelEndIcon.setObjectName("labelEndIcon")
        self.horizontalLayout_6.addWidget(self.labelEndIcon)
        spacerItem17 = QtWidgets.QSpacerItem(40, 20, QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Minimum)
        self.horizontalLayout_6.addItem(spacerItem17)
        self.verticalLayout_8.addLayout(self.horizontalLayout_6)
        spacerItem18 = QtWidgets.QSpacerItem(20, 20, QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.MinimumExpanding)
        self.verticalLayout_8.addItem(spacerItem18)
        self.labelEnd1 = QtWidgets.QLabel(self.pageEnd)
        font = QtGui.QFont()
        font.setPointSize(14)
        font.setBold(True)
        font.setWeight(75)
        self.labelEnd1.setFont(font)
        self.labelEnd1.setStyleSheet("color: rgb(61, 179, 158);")
        self.labelEnd1.setAlignment(QtCore.Qt.AlignCenter)
        self.labelEnd1.setObjectName("labelEnd1")
        self.verticalLayout_8.addWidget(self.labelEnd1)
        self.labelEnd2 = QtWidgets.QLabel(self.pageEnd)
        font = QtGui.QFont()
        font.setPointSize(13)
        self.labelEnd2.setFont(font)
        self.labelEnd2.setStyleSheet("color: rgb(61, 179, 158);")
        self.labelEnd2.setAlignment(QtCore.Qt.AlignCenter)
        self.labelEnd2.setObjectName("labelEnd2")
        self.verticalLayout_8.addWidget(self.labelEnd2)
        spacerItem19 = QtWidgets.QSpacerItem(20, 147, QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Expanding)
        self.verticalLayout_8.addItem(spacerItem19)
        self.stackedWidget.addWidget(self.pageEnd)
        self.verticalLayout_2.addWidget(self.stackedWidget)
        self.stackedWidgetButtons = QtWidgets.QStackedWidget(self.centralWidget)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Preferred, QtWidgets.QSizePolicy.Maximum)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.stackedWidgetButtons.sizePolicy().hasHeightForWidth())
        self.stackedWidgetButtons.setSizePolicy(sizePolicy)
        self.stackedWidgetButtons.setObjectName("stackedWidgetButtons")
        self.stackedWidgetButtonsDefault = QtWidgets.QWidget()
        self.stackedWidgetButtonsDefault.setObjectName("stackedWidgetButtonsDefault")
        self.horizontalLayout = QtWidgets.QHBoxLayout(self.stackedWidgetButtonsDefault)
        self.horizontalLayout.setContentsMargins(10, 10, 10, 10)
        self.horizontalLayout.setSpacing(10)
        self.horizontalLayout.setObjectName("horizontalLayout")
        self.pushButtonQuit = QtWidgets.QPushButton(self.stackedWidgetButtonsDefault)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Preferred, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.pushButtonQuit.sizePolicy().hasHeightForWidth())
        self.pushButtonQuit.setSizePolicy(sizePolicy)
        self.pushButtonQuit.setMinimumSize(QtCore.QSize(120, 0))
        icon = QtGui.QIcon.fromTheme("application-exit")
        self.pushButtonQuit.setIcon(icon)
        self.pushButtonQuit.setAutoDefault(True)
        self.pushButtonQuit.setObjectName("pushButtonQuit")
        self.horizontalLayout.addWidget(self.pushButtonQuit)
        spacerItem20 = QtWidgets.QSpacerItem(40, 20, QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Minimum)
        self.horizontalLayout.addItem(spacerItem20)
        self.pushButtonParameters = QtWidgets.QPushButton(self.stackedWidgetButtonsDefault)
        self.pushButtonParameters.setMinimumSize(QtCore.QSize(120, 0))
        icon = QtGui.QIcon.fromTheme("document-properties")
        self.pushButtonParameters.setIcon(icon)
        self.pushButtonParameters.setAutoDefault(True)
        self.pushButtonParameters.setObjectName("pushButtonParameters")
        self.horizontalLayout.addWidget(self.pushButtonParameters)
        spacerItem21 = QtWidgets.QSpacerItem(40, 20, QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Minimum)
        self.horizontalLayout.addItem(spacerItem21)
        self.pushButtonPrevious = QtWidgets.QPushButton(self.stackedWidgetButtonsDefault)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Fixed, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.pushButtonPrevious.sizePolicy().hasHeightForWidth())
        self.pushButtonPrevious.setSizePolicy(sizePolicy)
        self.pushButtonPrevious.setMinimumSize(QtCore.QSize(120, 0))
        icon = QtGui.QIcon.fromTheme("go-previous")
        self.pushButtonPrevious.setIcon(icon)
        self.pushButtonPrevious.setAutoDefault(True)
        self.pushButtonPrevious.setObjectName("pushButtonPrevious")
        self.horizontalLayout.addWidget(self.pushButtonPrevious)
        self.pushButtonNext = QtWidgets.QPushButton(self.stackedWidgetButtonsDefault)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Preferred, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.pushButtonNext.sizePolicy().hasHeightForWidth())
        self.pushButtonNext.setSizePolicy(sizePolicy)
        self.pushButtonNext.setMinimumSize(QtCore.QSize(119, 0))
        icon = QtGui.QIcon.fromTheme("go-next")
        self.pushButtonNext.setIcon(icon)
        self.pushButtonNext.setAutoDefault(True)
        self.pushButtonNext.setDefault(True)
        self.pushButtonNext.setObjectName("pushButtonNext")
        self.horizontalLayout.addWidget(self.pushButtonNext)
        self.stackedWidgetButtons.addWidget(self.stackedWidgetButtonsDefault)
        self.stackedWidgetButtonsParameters = QtWidgets.QWidget()
        self.stackedWidgetButtonsParameters.setObjectName("stackedWidgetButtonsParameters")
        self.horizontalLayout_5 = QtWidgets.QHBoxLayout(self.stackedWidgetButtonsParameters)
        self.horizontalLayout_5.setContentsMargins(10, 10, 10, 10)
        self.horizontalLayout_5.setSpacing(0)
        self.horizontalLayout_5.setObjectName("horizontalLayout_5")
        self.pushButtonParamCancel = QtWidgets.QPushButton(self.stackedWidgetButtonsParameters)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Preferred, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.pushButtonParamCancel.sizePolicy().hasHeightForWidth())
        self.pushButtonParamCancel.setSizePolicy(sizePolicy)
        self.pushButtonParamCancel.setMinimumSize(QtCore.QSize(110, 0))
        icon = QtGui.QIcon.fromTheme("dialog-cancel")
        self.pushButtonParamCancel.setIcon(icon)
        self.pushButtonParamCancel.setAutoDefault(True)
        self.pushButtonParamCancel.setObjectName("pushButtonParamCancel")
        self.horizontalLayout_5.addWidget(self.pushButtonParamCancel)
        spacerItem22 = QtWidgets.QSpacerItem(40, 20, QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Minimum)
        self.horizontalLayout_5.addItem(spacerItem22)
        self.pushButtonParamValidate = QtWidgets.QPushButton(self.stackedWidgetButtonsParameters)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Preferred, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.pushButtonParamValidate.sizePolicy().hasHeightForWidth())
        self.pushButtonParamValidate.setSizePolicy(sizePolicy)
        self.pushButtonParamValidate.setMinimumSize(QtCore.QSize(110, 0))
        icon = QtGui.QIcon.fromTheme("dialog-ok")
        self.pushButtonParamValidate.setIcon(icon)
        self.pushButtonParamValidate.setAutoDefault(True)
        self.pushButtonParamValidate.setObjectName("pushButtonParamValidate")
        self.horizontalLayout_5.addWidget(self.pushButtonParamValidate)
        self.stackedWidgetButtons.addWidget(self.stackedWidgetButtonsParameters)
        self.verticalLayout_2.addWidget(self.stackedWidgetButtons)
        Main_Window.setCentralWidget(self.centralWidget)

        self.retranslateUi(Main_Window)
        self.stackedWidget.setCurrentIndex(0)
        self.stackedWidgetButtons.setCurrentIndex(0)
        QtCore.QMetaObject.connectSlotsByName(Main_Window)
        Main_Window.setTabOrder(self.pushButtonNext, self.pushButtonAbout)
        Main_Window.setTabOrder(self.pushButtonAbout, self.textBrowserAbout)
        Main_Window.setTabOrder(self.textBrowserAbout, self.lineEditFile)
        Main_Window.setTabOrder(self.lineEditFile, self.pushButtonBrowse)
        Main_Window.setTabOrder(self.pushButtonBrowse, self.listWidget)
        Main_Window.setTabOrder(self.listWidget, self.pushButtonQuit)
        Main_Window.setTabOrder(self.pushButtonQuit, self.pushButtonParameters)
        Main_Window.setTabOrder(self.pushButtonParameters, self.pushButtonPrevious)
        Main_Window.setTabOrder(self.pushButtonPrevious, self.pushButtonParamValidate)
        Main_Window.setTabOrder(self.pushButtonParamValidate, self.pushButtonSearchDir)
        Main_Window.setTabOrder(self.pushButtonSearchDir, self.lineEditSearchDir)
        Main_Window.setTabOrder(self.lineEditSearchDir, self.pushButtonWorkDir)
        Main_Window.setTabOrder(self.pushButtonWorkDir, self.lineEditWorkDir)
        Main_Window.setTabOrder(self.lineEditWorkDir, self.lineEditMail)
        Main_Window.setTabOrder(self.lineEditMail, self.lineEditPassword)
        Main_Window.setTabOrder(self.lineEditPassword, self.lineEditSmtpServer)
        Main_Window.setTabOrder(self.lineEditSmtpServer, self.lineEditSmtpPort)
        Main_Window.setTabOrder(self.lineEditSmtpPort, self.lineEditExpeditorName)
        Main_Window.setTabOrder(self.lineEditExpeditorName, self.pushButtonParamCancel)

    def retranslateUi(self, Main_Window):
        _translate = QtCore.QCoreApplication.translate
        Main_Window.setWindowTitle(_translate("Main_Window", "DéclaTravaux"))
        self.labelTitle1.setText(_translate("Main_Window", "DéclaTravaux"))
        self.labelTitle2.setText(_translate("Main_Window", "Utilitaire de déclarations de travaux"))
        self.pushButtonAbout.setText(_translate("Main_Window", "À propos"))
        self.textBrowserAbout.setHtml(_translate("Main_Window", "<!DOCTYPE HTML PUBLIC \"-//W3C//DTD HTML 4.0//EN\" \"http://www.w3.org/TR/REC-html40/strict.dtd\">\n"
"<html><head><meta name=\"qrichtext\" content=\"1\" /><style type=\"text/css\">\n"
"p, li { white-space: pre-wrap; }\n"
"</style></head><body style=\" font-family:\'Ubuntu\'; font-size:10pt; font-weight:400; font-style:normal;\">\n"
"<p align=\"center\" style=\" margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;\"><span style=\" font-size:11pt;\">Utilitaire de télétransmission des DT, DICT et ATU.</span></p>\n"
"<p align=\"center\" style=\"-qt-paragraph-type:empty; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px; font-size:11pt;\"><br /></p>\n"
"<p align=\"center\" style=\" margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;\"><span style=\" font-size:11pt;\">Logiciel développé en Python par Pierre Gobin.</span></p>\n"
"<p align=\"center\" style=\"-qt-paragraph-type:empty; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px; font-size:11pt;\"><br /></p>\n"
"<p align=\"center\" style=\" margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;\"><span style=\" font-size:11pt;\">Disponible sous la licence libre CeCILL (</span><a href=\"http://www.cecill.info/\"><span style=\" font-size:11pt; text-decoration: underline; color:#0000ff;\">http://www.cecill.info/</span></a><span style=\" font-size:11pt;\">).</span></p>\n"
"<p align=\"center\" style=\"-qt-paragraph-type:empty; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px; font-size:11pt;\"><br /></p>\n"
"<p align=\"center\" style=\" margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;\"><span style=\" font-size:11pt;\">Images réalisées par </span><a href=\"https://www.flaticon.com/authors/pixel-buddha\"><span style=\" font-size:11pt; text-decoration: underline; color:#0000ff;\">Pixel Buddha</span></a><span style=\" font-size:11pt;\"> sur </span><a href=\"https://www.flaticon.com\"><span style=\" font-size:11pt; text-decoration: underline; color:#0000ff;\">www.flaticon.com</span></a><span style=\" font-size:11pt;\">.</span></p>\n"
"<p align=\"center\" style=\"-qt-paragraph-type:empty; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px; font-size:11pt;\"><br /></p>\n"
"<p align=\"center\" style=\" margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;\"><span style=\" font-size:11pt;\">Plus d\'informations sur </span><a href=\"https://framagit.org/Pierre86/DeclaTravaux\"><span style=\" font-size:11pt; text-decoration: underline; color:#0000ff;\">Framagit</span></a><span style=\" font-size:11pt;\">.</span></p></body></html>"))
        self.labelTitleParameters.setText(_translate("Main_Window", "Paramètres"))
        self.groupBox.setTitle(_translate("Main_Window", "Configuration"))
        self.labelSearchDir.setText(_translate("Main_Window", "Répertoire de recherche :"))
        self.labelWorkDir.setText(_translate("Main_Window", "Répertoire de traitement :"))
        self.pushButtonWorkDir.setText(_translate("Main_Window", "..."))
        self.pushButtonSearchDir.setText(_translate("Main_Window", "..."))
        self.groupBox_2.setTitle(_translate("Main_Window", "Courriels"))
        self.lineEditPassword.setPlaceholderText(_translate("Main_Window", "Mot de passe"))
        self.labelSmtpServer.setText(_translate("Main_Window", "Adresse du serveur SMTP :"))
        self.lineEditSmtpServer.setPlaceholderText(_translate("Main_Window", "smtp.domaine.com"))
        self.lineEditSmtpPort.setPlaceholderText(_translate("Main_Window", "Ex. : 465"))
        self.labelMail.setText(_translate("Main_Window", "Adresse électronique :"))
        self.lineEditExpeditorName.setPlaceholderText(_translate("Main_Window", "Prénom NOM"))
        self.labelSmtpPort.setText(_translate("Main_Window", "Port du serveur SMTP :"))
        self.label.setText(_translate("Main_Window", "Mot de passe :"))
        self.labelExpeditorName.setText(_translate("Main_Window", "Nom de l\'expéditeur :"))
        self.lineEditMail.setPlaceholderText(_translate("Main_Window", "exemple@domaine.com"))
        self.labelFileSelection.setText(_translate("Main_Window", "Sélectionner une archive :"))
        self.pushButtonBrowse.setText(_translate("Main_Window", "Parcourir..."))
        self.labelFileError.setText(_translate("Main_Window", "Le format de l\'archive sélectionnée est incorrect."))
        self.label_2.setText(_translate("Main_Window", "Plusieurs archives ont été trouvées."))
        self.label_3.setText(_translate("Main_Window", "Veuillez choisir la déclaration que vous souhaitez télétransmettre :"))
        self.labelConfirmation.setText(_translate("Main_Window", "<html><head/>\n"
"<style type=\"text/css\">\n"
"p {margin: 15px; line-height: 125; font-size: 14pt; text-align: center;}\n"
"#numero, #date {font-weight: bold;}\n"
"</style>\n"
"<body>\n"
"<p>\n"
"La déclaration n<span style=\"vertical-align: super;\">o</span> <span id=\"numero\">XXX</span> du <span id=\"date\">JJ MMMM AAAA</span>\n"
"<br />\n"
"a été sélectionnée.</p>\n"
"<p>Souhaitez-vous procéder à sa télétransmission ?</p>\n"
"</body>\n"
"</html>"))
        self.progressBar.setFormat(_translate("Main_Window", "%p %"))
        self.labelStep.setText(_translate("Main_Window", "Extraction de l\'archive..."))
        self.labelEnd1.setText(_translate("Main_Window", "La déclaration a été télétransmise."))
        self.labelEnd2.setText(_translate("Main_Window", "Un courriel récapitulatif a été envoyé à xxx@domaine.tld"))
        self.pushButtonQuit.setText(_translate("Main_Window", "Quitter"))
        self.pushButtonParameters.setText(_translate("Main_Window", "Paramètres"))
        self.pushButtonPrevious.setText(_translate("Main_Window", "Précédent"))
        self.pushButtonNext.setText(_translate("Main_Window", "Démarrer"))
        self.pushButtonParamCancel.setText(_translate("Main_Window", "Annuler"))
        self.pushButtonParamValidate.setText(_translate("Main_Window", "Valider"))

